<?php
if ( ! defined( 'WPINC' ) ) {
	exit;
}
return json_decode( '{"lastScanTimestamp": 1779601088, "nextScanTimestamp": 1780185600.0, "username": "avicolau", "malware": [{"id": 10052739, "username": "avicolau", "file": "/home/avicolau/public_html/evenimentultau.eu/wp-content/themes/twentytwentytwo/styles/imunify-security/index.php", "created": 1779528076, "scan_id": "5634313a9b2a4f27af4628d88588e03f", "scan_type": "rescan", "resource_type": "file", "type": "SMW-BLKH-SA-CLOUDAV-php.bkdr.wshll.obf-NP1469-0", "hash": "9303784398fabd0a8b947559b29279b4f77075fc0e582cf0d8d06968e65633b1", "size": "97693", "malicious": true, "status": "cleanup_removed", "cleaned_at": 1779528108.1780279, "extra_data": {}, "db_name": null, "app_name": null, "db_host": null, "db_port": null, "snippet": null, "table_fields": []}], "config": {"MALWARE_SCANNING": {"enable_scan_cpanel": true, "default_action": "cleanup"}, "PROACTIVE_DEFENCE": {"blamer": true}}, "license": {"status": true, "expiration": null, "user_limit": 2147483647, "id": "IP-45375-617319-q3JSOjIy", "user_count": 717, "message": "", "license_type": "imunify360", "upgrade_url": null, "upgrade_url_360": null, "redirect_url": "https://cln.cloudlinux.com/console/imunify360/servers/IP-45375-617319-q3JSOjIy/products/IM_UN/convert", "eligible_for_imunify_patch": false}}', true );